import { AsyncQueue, createAsyncQueue } from 'common/AsyncQueue'
import { singleton } from 'decorators/singleton'
import logger from 'logger/logger'
import { MailService } from 'services/MailService'
import { Deferred } from 'utils/promise.util'

@singleton
export class MailQueue {
  private queue: AsyncQueue
  constructor() {
    this.queue = createAsyncQueue()
  }

  public async addTaskToQueue(data: any) {
    let deferred = new Deferred()
    this.queue.push(async () => {
      try {
        let info = await new MailService().send(data)
        logger.info(
          `send mail success:: from: ${data.from}, to: ${data.to}, subject: ${data.subject}, messageId: ${info.messageId}`,
        )
        deferred.resolve(info)
      } catch (err) {
        logger.info(`send mail error:: from: ${data.from}, to: ${data.to}, subject: ${data.subject}`)
        logger.error(err)
        deferred.reject(err)
      }
    })
    return deferred.promise
  }
}
