export const RE_URL_SCHEME = /^(.+?):\/\/.+?$/;

/**
 * 获取url中的scheme
 * @param url
 * @returns
 */
export function findUrlScheme(url: string) {
  let result = url.match(RE_URL_SCHEME);
  if (!result) {
    return "";
  }
  return result[1];
}

/**
 * 生成 key1=val1&key2=val2的字符串
 * @param {object} data 需要处理的对象
 * @param {boolean} sort 是否按key生序重排
 * @param {boolean} ignoreNull 是否过滤空值(空格或者null值不参与拼接)
 * @param splitChar 连接的字符, 默认是&
 * @param equalChar =
 */
export function generateKVStr({
  data = {},
  sort = false,
  ignoreNull = true,
  splitChar = "&",
  equalChar = "=",
  uri = "",
}: {
  data?: any;
  sort?: boolean;
  ignoreNull?: boolean;
  splitChar?: string;
  equalChar?: string;
  uri?: string;
}) {
  const keys = Object.keys(data);
  sort && keys.sort();
  let result = "";
  let i = 0;
  for (let key of keys) {
    if (ignoreNull && !data[key]) {
      continue;
    }
    if (i++ > 0) result += splitChar;
    result += `${key}${equalChar}${data[key]}`;
  }
  if (uri) {
    const joinChar = uri.search(/\?/) === -1 ? "?" : "&";
    result = uri + joinChar + result;
  }
  return result;
}

/**
 * 将key1=val&key2=val的字符串组装成对象
 * @param str key1=val&key2=val的字符串
 * @param splitChar 连接的字符, 默认是&
 * @param equalChar =
 */
export function keyValToObject(
  str: string,
  splitChar: string = "&",
  equalChar = "="
): {} {
  let result: any = {};
  if (!str) {
    return result;
  }
  let arrs = str.split(splitChar);
  for (let sub of arrs) {
    let subArr = sub.split(equalChar);
    result[subArr[0]] = subArr[1];
  }
  return result;
}

/**
 * 解析jwt token中的用户信息, 不校验签名
 * @param token
 * @returns
 */
export function decodeJWT(token: string) {
  let strings = token.split(".");
  var userinfo = JSON.parse(
    decodeURIComponent(
      encodeURIComponent(
        window.atob(strings[1].replace(/-/g, "+").replace(/_/g, "/"))
      )
    )
  );
  return userinfo;
}
