/**
 * 判断传入的值是否为true
 * @param {Object} obj   传入值为'true','TRUE',1,'1','on','ON','YES','yes'时,返回true,其他值均返回false
 * @return {boolean}
 */
export function isTrue(obj: any) {
  return (
    obj === "true" ||
    obj === "TRUE" ||
    obj === "True" ||
    obj === "on" ||
    obj === "ON" ||
    obj === true ||
    obj === 1 ||
    obj === "1" ||
    obj === "YES" ||
    obj === "yes"
  );
}

/**
 * 验证ObjectId格式是否正确
 * @param {string} id
 * @return {boolean}
 */
export function isObjectId(id: string): boolean {
  //mongoose.Types.ObjectId.isValid(id)
  return /^[a-fA-F0-9]{24}$/.test(id);
}

/**
 * 10进制 -> 62进制
 * @param {string | number} number
 * @return {string}
 */
export function string10to62(number: string | number) {
  const chars =
    "0123456789abcdefghigklmnopqrstuvwxyzABCDEFGHIGKLMNOPQRSTUVWXYZ".split("");
  const radix = chars.length;
  let qutient = +number;
  const arr = [];
  do {
    const mod = qutient % radix;
    qutient = (qutient - mod) / radix;
    arr.unshift(chars[mod]);
  } while (qutient);
  return arr.join("");
}

/**
 * 62进制 -> 10 进制
 * @param {string} numberCode
 * @return {number}
 */
export function string62to10(numberCode: string) {
  const chars =
    "0123456789abcdefghigklmnopqrstuvwxyzABCDEFGHIGKLMNOPQRSTUVWXYZ";
  const radix = chars.length;
  numberCode = numberCode + "";
  const len = numberCode.length;
  let i = 0;
  let originNumber = 0;
  while (i < len) {
    originNumber +=
      Math.pow(radix, i++) * (chars.indexOf(numberCode.charAt(len - i)) || 0);
  }
  return originNumber;
}

/**
 * 判断是否是json格式的字符串
 * @param {string} str
 * @return {boolean}
 */
export function isJsonString(str: string) {
  try {
    if (typeof JSON.parse(str) == "object") {
      return true;
    }
  } catch (e) {}
  return false;
}
/**
 * 检查accountId是否符合规则
 * 4位渠道id_4位游戏id_openid
 * @param accountId
 * @returns
 */
export function checkAccountId(accountId: string) {
  return /^\d{4}_\d{4,6}_.+$/.test(accountId);
}
/**
 * 将accountId拆分出 渠道id, 游戏id, 和openId
 * @param accountId
 * @returns
 */
export function parseGameAccountId(accountId: string) {
  const arr = accountId.split("_");
  const gameId = arr[1];
  const channel = arr[0];
  const openId = arr[2];
  return { gameId, channel, openId };
}
